import streamlit as st
from __init__ import chip_filter

st.set_page_config(layout="wide")

data = [
    { "index": 0, "label": "Marksman", "clicked": True },
    { "index": 1, "label": "Tank", "clicked": False },
    { "index": 2, "label": "Mage", "clicked": False },
    { "index": 3, "label": "Fghter", "clicked": False },
    { "index": 4, "label": "Support", "clicked": False },
    { "index": 5, "label": "Assassin", "clicked": False },
    { "index": 6, "label": "Assassin", "clicked": False },
  ]

if "test" not in st.session_state:
    st.session_state["test"] = data 



test = chip_filter(chipData=data) 
# st.session_state["test"] = test





import os
import streamlit as st
import streamlit.components.v1 as components
from chip_component.streamlit_callback import register 

_RELEASE = False 

if not _RELEASE:
    _chip_filter= components.declare_component(
        
        "chip_filter",

        url="http://localhost:3001",
    )
else:

    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _chip_filter = components.declare_component("chip_filter", path=build_dir)

def chip_filter(chipData=None, styles=None, key=None, on_change=None, args=None, kwargs=None, default=None):

    if on_change is not None:
        if key is None:
            st.error("You must pass a key if you want to use the on_change callback for the chip filter")
        else:
            register(key=key, callback=on_change, args=args, kwargs=kwargs)
    
    component_value = _chip_filter(chipData=chipData, styles=styles, key=key, default=default)

    return component_value
